from pydantic import BaseModel
from typing import List


# The type def for a nav item link accessible on the Shopify docs
class NavItemLink(BaseModel):
    key: str # Key for DOM
    label: str # Human readable but code label (ie cartTransforms)
    href: str # The path to be appended to "https://shopify.dev/"
    monospace: bool # Appears to be true for most but keeping nonetheless


# The type def for a nav item child accessible on the Shopify docs
class NavItemChild(BaseModel):
    key: str # Key for DOM
    label: str # Human readable label (Queries, Mutations, Objects)
    children: List[NavItemLink] # A list of links referencing different APIs for this category

# Represents a single item that gets presented in the nav bar consisting of all APIs
class NavItem(BaseModel):
    key: str # Key for DOM
    label: str # Human readable label (top level)
    children: List[NavItemChild] # A list of types of APIs (queries, mutations, objects)

# The type def for a part of the overall Shopify docs nav
class ShopifyNavResponse(BaseModel):
    navItems: List[NavItem] # A collection of all nav items



from pydantic import BaseModel
from typing import List, Optional

# The type def for a code example belonging to an graphql operation
class CodeExample(BaseModel):
    description: str
    code: str


# The type def for an argument belonging to a graphql mutation
class MutationArgument(BaseModel):
    name: str
    type: str
    required: Optional[bool]
    description: str


# The type def for a return value provided by a graphql mutation
class MutationReturn(BaseModel):
    name: str
    type: str
    description: str


# The type def for a graphql mutation offered by the Shopify API
class Mutation(BaseModel):
    name: str
    description: str
    arguments: List[MutationArgument]
    returns: List[MutationReturn]
    examples: List[CodeExample]


# The type def for a field or connection available to an object
class ObjectFieldOrConnection(BaseModel):
    name: str
    type: str
    description: str
    not_nullable: Optional[bool]


# The type def for a query involving a graphql object
class ObjectQuery(BaseModel):
    name: str
    type: str
    description: str


# The type def for an interface involving a graphql object
class ObjectInterface(BaseModel):
    name: str


# The type def for a graphql object offered by the Shopify API
class Object(BaseModel):
    name: str
    description: str
    fields_and_connections: List[ObjectFieldOrConnection]
    examples: List[CodeExample]


# The type def for an argument that can be provided to a particular graphql query
class QueryArgument(BaseModel):
    name: str
    type: str
    required: Optional[bool]
    description: str


# The type def for a possible return value for a graphql query
class QueryReturn(BaseModel):
    name: str
    type: str
    description: str


# The type def for a graphql query offered by the Shopify API
class Query(BaseModel):
    name: str
    description: str
    arguments: List[QueryArgument]
    returns: List[QueryReturn]
    examples: List[CodeExample]


# The type def for a breakdown of an API offered by Shopify
class ShopifyAPIBreakdown(BaseModel):
    name: str
    queries: List[Query]
    mutations: List[Mutation]
    objects: List[Object]


# The type def for the overall Shopify API
class ShopifyAPI(BaseModel):
    categories: List[ShopifyAPIBreakdown]
